@@ -12,17 +12,13 @@
 #include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
-#include <syslog.h>
 #include <unistd.h>
 #include "error.h"
 
 int become_daemon(void)
 {
 	if (daemon(0, 0) == -1)
-	{
 		error_exit("become_daemon::daemon: failed");
-		return -1;
-	}
 
 	return 0;
 }
@@ -31,10 +27,7 @@ int write_pidfile(char *fname)
 {
 	FILE *fh = fopen(fname, "w");
         if (!fh)
-	{
 		error_exit("write_pidfile::fopen: failed creating file %s", fname);
-		return -1;
-	}
 
         fprintf(fh, "%i", getpid());
 
